"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BenefitGrantDiscordPropertiesTypedDict(TypedDict):
    account_id: NotRequired[str]
    guild_id: NotRequired[str]
    role_id: NotRequired[str]


class BenefitGrantDiscordProperties(BaseModel):
    account_id: Optional[str] = None

    guild_id: Optional[str] = None

    role_id: Optional[str] = None
