"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from polar_sdk.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class S3DownloadURLTypedDict(TypedDict):
    url: str
    expires_at: datetime
    headers: NotRequired[Dict[str, str]]


class S3DownloadURL(BaseModel):
    url: str

    expires_at: datetime

    headers: Optional[Dict[str, str]] = None
