"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SubscriptionSortProperty(str, Enum):
    CUSTOMER = "customer"
    MINUS_CUSTOMER = "-customer"
    STATUS = "status"
    MINUS_STATUS = "-status"
    STARTED_AT = "started_at"
    MINUS_STARTED_AT = "-started_at"
    CURRENT_PERIOD_END = "current_period_end"
    MINUS_CURRENT_PERIOD_END = "-current_period_end"
    AMOUNT = "amount"
    MINUS_AMOUNT = "-amount"
    PRODUCT = "product"
    MINUS_PRODUCT = "-product"
    DISCOUNT = "discount"
    MINUS_DISCOUNT = "-discount"
