"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CustomerSessionCreateTypedDict(TypedDict):
    r"""Schema for creating a customer session."""

    customer_id: str
    r"""ID of the customer to create a session for."""


class CustomerSessionCreate(BaseModel):
    r"""Schema for creating a customer session."""

    customer_id: str
    r"""ID of the customer to create a session for."""
