"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .discountfixedonceforeverduration import (
    DiscountFixedOnceForeverDuration,
    DiscountFixedOnceForeverDurationTypedDict,
)
from .discountfixedrepeatduration import (
    DiscountFixedRepeatDuration,
    DiscountFixedRepeatDurationTypedDict,
)
from .discountpercentageonceforeverduration import (
    DiscountPercentageOnceForeverDuration,
    DiscountPercentageOnceForeverDurationTypedDict,
)
from .discountpercentagerepeatduration import (
    DiscountPercentageRepeatDuration,
    DiscountPercentageRepeatDurationTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


DiscountTypedDict = TypeAliasType(
    "DiscountTypedDict",
    Union[
        DiscountPercentageOnceForeverDurationTypedDict,
        DiscountFixedOnceForeverDurationTypedDict,
        DiscountPercentageRepeatDurationTypedDict,
        DiscountFixedRepeatDurationTypedDict,
    ],
)


Discount = TypeAliasType(
    "Discount",
    Union[
        DiscountPercentageOnceForeverDuration,
        DiscountFixedOnceForeverDuration,
        DiscountPercentageRepeatDuration,
        DiscountFixedRepeatDuration,
    ],
)
