"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productonetimecreate import ProductOneTimeCreate, ProductOneTimeCreateTypedDict
from .productrecurringcreate import (
    ProductRecurringCreate,
    ProductRecurringCreateTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


ProductCreateTypedDict = TypeAliasType(
    "ProductCreateTypedDict",
    Union[ProductRecurringCreateTypedDict, ProductOneTimeCreateTypedDict],
)


ProductCreate = TypeAliasType(
    "ProductCreate", Union[ProductRecurringCreate, ProductOneTimeCreate]
)
