"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customerbenefitgrantupdate import (
    CustomerBenefitGrantUpdate,
    CustomerBenefitGrantUpdateTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CustomerPortalBenefitGrantsUpdateRequestTypedDict(TypedDict):
    id: str
    r"""The benefit grant ID."""
    customer_benefit_grant_update: CustomerBenefitGrantUpdateTypedDict


class CustomerPortalBenefitGrantsUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The benefit grant ID."""

    customer_benefit_grant_update: Annotated[
        CustomerBenefitGrantUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
