"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .repository import Repository, RepositoryTypedDict
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListResourceRepositoryTypedDict(TypedDict):
    items: List[RepositoryTypedDict]
    pagination: PaginationTypedDict


class ListResourceRepository(BaseModel):
    items: List[Repository]

    pagination: Pagination
