"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class OrderBillingReason(str, Enum):
    PURCHASE = "purchase"
    SUBSCRIPTION_CREATE = "subscription_create"
    SUBSCRIPTION_CYCLE = "subscription_cycle"
    SUBSCRIPTION_UPDATE = "subscription_update"
